@@ -15,7 +15,6 @@ import warnings
 warnings.simplefilter(action='ignore', category=FutureWarning)
 warnings.simplefilter(action='ignore', category=Warning)
 warnings.simplefilter(action='ignore', category=DeprecationWarning)
-warnings.simplefilter(action='ignore', category=FutureWarning)
 warnings.simplefilter(action='ignore', category=RuntimeWarning)
 import subprocess
 import random
@@ -46,6 +45,7 @@ from onnx2tf.utils.common_functions import (
     download_test_image_data,
     get_tf_model_inputs,
     get_tf_model_outputs,
+    rewrite_tflite_inout_opname,
 )
 from onnx2tf.utils.colors import Color
 from sng4onnx import generate as op_name_auto_generate
@@ -58,6 +58,7 @@ def convert(
     output_signaturedefs: Optional[bool] = False,
     output_h5: Optional[bool] = False,
     output_weights: Optional[bool] = False,
+    copy_onnx_input_output_names_to_tflite: Optional[bool] = False,
     output_integer_quantized_tflite: Optional[bool] = False,
     quant_type: Optional[str] = 'per-channel',
     quant_calib_input_op_name_np_data_path: Optional[List] = None,
@@ -66,6 +67,7 @@ def convert(
     not_use_opname_auto_generate: Optional[bool] = False,
     batch_size: Optional[int] = None,
     overwrite_input_shape: Optional[List[str]] = None,
+    no_large_tensor: Optional[bool] = False,
     output_nms_with_dynamic_tensor: Optional[bool] = False,
     keep_ncw_or_nchw_or_ncdhw_input_names: Optional[List[str]] = None,
     keep_nwc_or_nhwc_or_ndhwc_input_names: Optional[List[str]] = None,
@@ -120,6 +122,17 @@ def convert(
     output_weights: Optional[bool]
         Output weights in hdf5 format.
 
+    copy_onnx_input_output_names_to_tflite: Optional[bool]
+        Copy the input/output OP name of ONNX to the input/output OP name of tflite.\n
+        Due to Tensorflow internal operating specifications,\n
+        the input/output order of ONNX does not necessarily match\n
+        the input/output order of tflite.\n
+        Be sure to check that the input/output OP names in the generated\n
+        tflite file have been converted as expected.\n
+        Also, this option generates a huge JSON file as a temporary file for processing.\n
+        Therefore, it is strongly discouraged to use it on large models of hundreds\n
+        of megabytes or more.
+
     output_integer_quantized_tflite: Optional[bool]
         Output of integer quantized tflite.
 
@@ -209,6 +222,10 @@ def convert(
         Numerical values other than dynamic dimensions are ignored.\n
         Ignores batch_size if specified at the same time as batch_size.
 
+    no_large_tensor: Optional[bool]
+        Suppresses constant bloat caused by Tile OP when optimizing models in onnxsim.\n
+        See: https://github.com/daquexian/onnx-simplifier/issues/178
+
     output_nms_with_dynamic_tensor: Optional[bool]
         The number of bounding boxes in the NMS output results is\n
         not fixed at the maximum number of max_output_boxes_per_class,\n
@@ -484,6 +501,10 @@ def convert(
         try:
             with open(param_replacement_file, 'r') as f:
                 replacement_parameters = json.load(f)['operations']
+                for operations in replacement_parameters:
+                    operations['op_name'] = operations['op_name'].replace(':','_')
+                    if output_signaturedefs:
+                        operations['op_name'] = re.sub('^/', 'wa/', operations['op_name'])
         except json.decoder.JSONDecodeError as ex:
             print(
                 f'{Color.RED}ERROR:{Color.RESET} ' +
@@ -504,6 +525,8 @@ def convert(
             for _ in range(3):
                 append_param = list(['--overwrite-input-shape'] + overwrite_input_shape) \
                     if overwrite_input_shape is not None else []
+                append_param = append_param + ['--no-large-tensor'] \
+                    if no_large_tensor else append_param
                 result = subprocess.check_output(
                     [
                         'onnxsim',
@@ -667,6 +690,13 @@ def convert(
         print(f'{Color.REVERCE}Model convertion started{Color.RESET}', '=' * 60)
 
     with graph.node_ids():
+        onnx_graph_input_names: List[str] = [
+            inputop.name for inputop in graph.inputs
+        ]
+        onnx_graph_output_names: List[str] = [
+            outputop.name for outputop in graph.outputs
+        ]
+
         # Inputs
         for graph_input in graph.inputs:
             """
@@ -743,6 +773,12 @@ def convert(
             output_names=output_names,
         )
 
+        # Bring back output names from ONNX model
+        for output, name in zip(outputs, output_names):
+            output.node.layer._name = name.replace(':','_')
+            if output_signaturedefs:
+                output.node.layer._name = re.sub('^/', '', output.node.layer._name)
+
         model = tf.keras.Model(inputs=inputs, outputs=outputs)
         if not non_verbose:
             print('')
@@ -824,6 +860,13 @@ def convert(
         tflite_model = converter.convert()
         with open(f'{output_folder_path}/{output_file_name}_float32.tflite', 'wb') as w:
             w.write(tflite_model)
+        if copy_onnx_input_output_names_to_tflite:
+            rewrite_tflite_inout_opname(
+                output_folder_path=output_folder_path,
+                tflite_file_name=f'{output_file_name}_float32.tflite',
+                onnx_input_names=onnx_graph_input_names,
+                onnx_output_names=onnx_graph_output_names,
+            )
         if output_weights:
             weights_export(
                 extract_target_tflite_file_path=f'{output_folder_path}/{output_file_name}_float32.tflite',
@@ -841,6 +884,13 @@ def convert(
         tflite_model = converter.convert()
         with open(f'{output_folder_path}/{output_file_name}_float16.tflite', 'wb') as w:
             w.write(tflite_model)
+        if copy_onnx_input_output_names_to_tflite:
+            rewrite_tflite_inout_opname(
+                output_folder_path=output_folder_path,
+                tflite_file_name=f'{output_file_name}_float16.tflite',
+                onnx_input_names=onnx_graph_input_names,
+                onnx_output_names=onnx_graph_output_names,
+            )
         if output_weights:
             weights_export(
                 extract_target_tflite_file_path=f'{output_folder_path}/{output_file_name}_float16.tflite',
@@ -884,6 +934,13 @@ def convert(
                 tflite_model = converter.convert()
                 with open(f'{output_folder_path}/{output_file_name}_dynamic_range_quant.tflite', 'wb') as w:
                     w.write(tflite_model)
+                if copy_onnx_input_output_names_to_tflite:
+                    rewrite_tflite_inout_opname(
+                        output_folder_path=output_folder_path,
+                        tflite_file_name=f'{output_file_name}_dynamic_range_quant.tflite',
+                        onnx_input_names=onnx_graph_input_names,
+                        onnx_output_names=onnx_graph_output_names,
+                    )
                 if output_weights:
                     weights_export(
                         extract_target_tflite_file_path=f'{output_folder_path}/{output_file_name}_dynamic_range_quant.tflite',
@@ -965,6 +1022,13 @@ def convert(
                 tflite_model = converter.convert()
                 with open(f'{output_folder_path}/{output_file_name}_integer_quant.tflite', 'wb') as w:
                     w.write(tflite_model)
+                if copy_onnx_input_output_names_to_tflite:
+                    rewrite_tflite_inout_opname(
+                        output_folder_path=output_folder_path,
+                        tflite_file_name=f'{output_file_name}_integer_quant.tflite',
+                        onnx_input_names=onnx_graph_input_names,
+                        onnx_output_names=onnx_graph_output_names,
+                    )
                 if output_weights:
                     weights_export(
                         extract_target_tflite_file_path=f'{output_folder_path}/{output_file_name}_integer_quant.tflite',
@@ -994,6 +1058,13 @@ def convert(
                 tflite_model = converter.convert()
                 with open(f'{output_folder_path}/{output_file_name}_full_integer_quant.tflite', 'wb') as w:
                     w.write(tflite_model)
+                if copy_onnx_input_output_names_to_tflite:
+                    rewrite_tflite_inout_opname(
+                        output_folder_path=output_folder_path,
+                        tflite_file_name=f'{output_file_name}_full_integer_quant.tflite',
+                        onnx_input_names=onnx_graph_input_names,
+                        onnx_output_names=onnx_graph_output_names,
+                    )
                 if output_weights:
                     weights_export(
                         extract_target_tflite_file_path=f'{output_folder_path}/{output_file_name}_full_integer_quant.tflite',
@@ -1026,6 +1097,13 @@ def convert(
                 tflite_model = converter.convert()
                 with open(f'{output_folder_path}/{output_file_name}_integer_quant_with_int16_act.tflite', 'wb') as w:
                     w.write(tflite_model)
+                if copy_onnx_input_output_names_to_tflite:
+                    rewrite_tflite_inout_opname(
+                        output_folder_path=output_folder_path,
+                        tflite_file_name=f'{output_file_name}_integer_quant_with_int16_act.tflite',
+                        onnx_input_names=onnx_graph_input_names,
+                        onnx_output_names=onnx_graph_output_names,
+                    )
                 if not non_verbose:
                     print(f'{Color.GREEN}INT8 Quantization with int16 activations tflite output complete!{Color.RESET}')
             except RuntimeError as ex:
@@ -1053,6 +1131,13 @@ def convert(
                 tflite_model = converter.convert()
                 with open(f'{output_folder_path}/{output_file_name}_full_integer_quant_with_int16_act.tflite', 'wb') as w:
                     w.write(tflite_model)
+                if copy_onnx_input_output_names_to_tflite:
+                    rewrite_tflite_inout_opname(
+                        output_folder_path=output_folder_path,
+                        tflite_file_name=f'{output_file_name}_full_integer_quant_with_int16_act.tflite',
+                        onnx_input_names=onnx_graph_input_names,
+                        onnx_output_names=onnx_graph_output_names,
+                    )
                 if not non_verbose:
                     print(f'{Color.GREEN}Full INT8 Quantization with int16 activations tflite output complete!{Color.RESET}')
             except RuntimeError as ex:
@@ -1291,6 +1376,21 @@ def main():
         help=\
             'Output weights in hdf5 format.'
     )
+    parser.add_argument(
+        '-coion',
+        '--copy_onnx_input_output_names_to_tflite',
+        action='store_true',
+        help=\
+            'Copy the input/output OP name of ONNX to the input/output OP name of tflite. \n' +
+            'Due to Tensorflow internal operating specifications, \n' +
+            'the input/output order of ONNX does not necessarily match \n' +
+            'the input/output order of tflite. \n' +
+            'Be sure to check that the input/output OP names in the generated \n' +
+            'tflite file have been converted as expected. \n' +
+            'Also, this option generates a huge JSON file as a temporary file for processing. \n' +
+            'Therefore, it is strongly discouraged to use it on large models of hundreds \n'
+            'of megabytes or more.'
+    )
     parser.add_argument(
         '-oiqt',
         '--output_integer_quantized_tflite',
@@ -1412,6 +1512,14 @@ def main():
             'Numerical values other than dynamic dimensions are ignored. \n' +
             'Ignores --batch_size if specified at the same time as --batch_size.'
     )
+    parser.add_argument(
+        '-nlt',
+        '--no_large_tensor',
+        action='store_true',
+        help=\
+            'Suppresses constant bloat caused by Tile OP when optimizing models in onnxsim. \n' +
+            'See: https://github.com/daquexian/onnx-simplifier/issues/178'
+    )
     parser.add_argument(
         '-onwdt',
         '--output_nms_with_dynamic_tensor',
@@ -1723,6 +1831,7 @@ def main():
         output_signaturedefs=args.output_signaturedefs,
         output_h5=args.output_h5,
         output_weights=args.output_weights,
+        copy_onnx_input_output_names_to_tflite=args.copy_onnx_input_output_names_to_tflite,
         output_integer_quantized_tflite=args.output_integer_quantized_tflite,
         quant_type=args.quant_type,
         quant_calib_input_op_name_np_data_path=calib_params,
@@ -1731,6 +1840,7 @@ def main():
         not_use_opname_auto_generate=args.not_use_opname_auto_generate,
         batch_size=args.batch_size,
         overwrite_input_shape=args.overwrite_input_shape,
+        no_large_tensor=args.no_large_tensor,
         output_nms_with_dynamic_tensor=args.output_nms_with_dynamic_tensor,
         keep_ncw_or_nchw_or_ncdhw_input_names=args.keep_ncw_or_nchw_or_ncdhw_input_names,
         keep_nwc_or_nhwc_or_ndhwc_input_names=args.keep_nwc_or_nhwc_or_ndhwc_input_names,
