@@ -9,11 +9,15 @@ from onnx2tf.utils.common_functions import (
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
+    get_replacement_parameter,
+    pre_process_transpose,
+    post_process_transpose,
 )
 
 
 @print_node_info
 @inverted_operation_enable_disable
+@get_replacement_parameter
 def make_node(
     *,
     graph_node: gs.Node,
@@ -37,7 +41,7 @@ def make_node(
         before_op_output_shape_trans = \
             before_op_output_shape_trans and before_op_output_shape_trans_n
 
-    inputs = []
+    values = []
     for graph_node_input in graph_node.inputs:
         graph_node_input_perm = get_constant_or_variable(
             graph_node_input,
@@ -45,7 +49,7 @@ def make_node(
         )
         input_tensor = tf_layers_dict[graph_node_input_perm.name]['tf_node'] \
             if isinstance(graph_node_input_perm, gs.Variable) else graph_node_input_perm
-        inputs.append(input_tensor)
+        values.append(input_tensor)
     graph_node_output: gs.Variable = graph_node.outputs[0]
     shape = graph_node_output.shape
     dtype = graph_node_output.dtype
@@ -59,16 +63,36 @@ def make_node(
         'dtype': dtype,
     }
 
+    # Pre-process transpose
+    new_values = []
+    for graph_node_input, value in zip(graph_node.inputs, values):
+        value = pre_process_transpose(
+            value_before_transpose=value,
+            param_target='inputs',
+            param_name=graph_node_input.name,
+            **kwargs,
+        )
+        new_values.append(value)
+    values = new_values
+
     # Generation of TF OP
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.einsum(
             equation,
-            *inputs,
+            *values,
             name=graph_node.name,
         )
 
+    # Post-process transpose
+    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     # Generation of Debug Info
-    tf_inputs = {f"input{idx}": input for idx, input in enumerate(inputs)}
+    tf_inputs = {f"input{idx}": input for idx, input in enumerate(values)}
     tf_inputs['equation'] = equation
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
         make_tf_node_info(
