@@ -58,7 +58,7 @@ def make_node(
     slope = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
         if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
 
-    replace_prelu_to_pseudo_prelu = kwargs['replace_prelu_to_pseudo_prelu']
+    replace_prelu_to_pseudo_prelu = "prelu" in kwargs['replace_to_pseudo_operators']
 
     _, slope = pre_explicit_broadcast(
         input_tensor_1=input_tensor,
@@ -87,12 +87,18 @@ def make_node(
     }
 
     # Pre-process transpose
+    before_trans_shape = input_tensor.shape
     input_tensor = pre_process_transpose(
         value_before_transpose=input_tensor,
         param_target='inputs',
         param_name=graph_node.inputs[0].name,
         **kwargs,
     )
+    after_trans_shape = input_tensor.shape
+    if 'nhwc' in tf_layers_dict[graph_node_output.name].keys() \
+        and tf_layers_dict[graph_node_output.name]['nhwc'] == True \
+        and before_trans_shape != after_trans_shape:
+        tf_layers_dict[graph_node_output.name].pop('nhwc')
 
     # Generation of TF OP
     if replace_prelu_to_pseudo_prelu:
@@ -107,12 +113,18 @@ def make_node(
         )(input_tensor)
 
     # Post-process transpose
+    before_trans_shape = tf_layers_dict[graph_node_output.name]['tf_node'].shape
     tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
         value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
         param_target='outputs',
         param_name=graph_node.outputs[0].name,
         **kwargs,
     )
+    after_trans_shape = tf_layers_dict[graph_node_output.name]['tf_node'].shape
+    if 'nhwc' in tf_layers_dict[graph_node_output.name].keys() \
+        and tf_layers_dict[graph_node_output.name]['nhwc'] == True \
+        and before_trans_shape != after_trans_shape:
+        tf_layers_dict[graph_node_output.name].pop('nhwc')
 
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
